# flake8: noqa
from service.stats.boot_time import Boot
from service.stats.cpu import Cpu
from service.stats.disk import Disk
from service.stats.memory import Memory
from service.stats.network import Network
from service.stats.system import System
from service.slack import Slack
